<?php

class imaxForm extends Module {

    function __construct($modulePath='', $action = '', $method = 'post', $name = '', $enctype = '') {
        if ($action == '') {
            $action = Tools::safeOutput($_SERVER['REQUEST_URI']);
        }
        if ($enctype != '') {
            $enctype = 'enctype="' . $enctype . '"';
        }
        $this->formulario = '<form name="' . $name . '" action="' . $action . '" method="' . $method . '" ' . $enctype . '>';
        $this->context = Context::getContext();
        $this->_path = $modulePath;
        $this->addCSS('forms.css');
        $this->addJS('forms.js');
        parent::__construct();
    }

    function addToForm($html) {
        $this->formulario .= $html;
    }
    
    function renderForm() {
        $this->formulario .= '</form>';
        $formulario = $this->formulario;
        return $formulario;
    }

    /**
     * Crea un elemento informativo
     * @param string $text Texto a mostrar
     * @param string $class Clase del elemento (warning (defecto), confirm)
     * @param bool $html El texto contiene html  (No se traduce)
     */
    function createFormInfomationText($text, $class = 'warning', $html = false) {
        switch ($class) {
            case 'warning':
                $class = ' warning warn alert  alert-warning ';
                break;
            case 'confirm':
                $class = ' module_confirmation conf confirm alert alert-success ';
                break;
            default:
                break;
        }
        $html = '';
        $html .= '<div class="form-group">';
        $html .= '<div class="bootstrap imaxBootstrap">';
        $html .= '<p class="' . $class . '">';
        if($html == true) {
            $html .= $text;
        }else {
            $html .= $this->l($text);
        }
        $html .= '</div>';
        $html .= '</div>';
        $this->formulario .= $html;
    }

    /**
     * Crea un checkbox
     * @param string $name Nombre del checkbox
     * @param string $text Texto informativo
     * @param boolean $checked Marcado(true) o no(false), por defecto false
     * @param string $title Titulo
     */
    function createFormCheckboxGroup($name, $text, $checked = false, $title = '') {
        $marcado = '';
        if ($checked == true) {
            $marcado = ' checked="checked"';
        }
        $html = '';
        $html .= '<div class="form-group">';
        $html .= '<label for="' . $name . '" class="control-label col-lg-3">';
        $html .= '<span title="' . $title . '">';
        $html .= $this->l($text);
        $html .= '</span>';
        $html .= '</label>';
        $html .= '<div class="col-lg-3">';
        $html .= '<input type="checkbox" ' . $marcado . ' value="1" name="' . $name . '" id="' . $name . '">';
        $html .= '</div>';
        $html .= '</div>';
        $this->formulario .= $html;
    }

    function createFormRadioButtonGroup($datos, $name, $extras = false) {
        $html = '';
        $html .= '<div class="form-group">';
        $html .= '<label class="control-label col-lg-3">' . $name . '</label>';
        $html .= '<div class="col-lg-9">';
        foreach ($datos AS $indice => $dato) {
            $checked = '';
            if (isset($dato['checked']) && $dato['checked'] == 1) {
                $checked = ' checked="checked"';
            }
            $html .= '<div class="radio">';
            $html .= '<label>';
            $html .= '<input ' . $checked . ' type="radio" value="' . $dato['value'] . '" name="' . $dato['name'] . '"';
            
            if($extras && $extras[$indice]) {
                foreach($extras[$indice] AS $indiceExtras => $extra) {
                    $html .= $indiceExtras .'="'.$extra.'"';
                }
            }
            $html .= ' />';
            
            $html .= $dato['text'];
            $html .= '</label>';
            $html .= '</div>';
        }
        $html .= '</div>';
        $html .= '</div>';
        $this->formulario .= $html;
    }

    function createFormTextGroup($name, $value, $text, $title = '', $password = 0) {
        $tipo = 'text';
        if ($password == 1) {
            $tipo = 'password';
        }
        $html = '';
        $html .= '<div class="form-group">';
        $html .= '<label for="' . $name . '" class="control-label col-lg-3">';
        $html .= '<span title="' . $title . '">';
        $html .= $this->l($text);
        $html .= '</span>';
        $html .= '</label>';
        $html .= '<div class="col-lg-3">';
        $html .= '<input type="' . $tipo . '" value="' . $value . '" name="' . $name . '" id="' . $name . '">';
        $html .= '</div>';
        $html .= '</div>';
        $this->formulario .= $html;
    }

    function createFormSelectNumerico($name, $text, $defaultValue, $min, $max, $step = 1, $title = '') {
        $html = '';
        $html .= '<div class="form-group">';
        $html .= '<label for="' . $name . '" class="control-label col-lg-3">';
        $html .= '<span title="' . $title . '">';
        $html .= $this->l($text);
        $html .= '</span>';
        $html .= '</label>';
        $html .= '<div class="col-lg-3">';
        $html .= '<select name="' . $name . '" id="' . $name . '">';
        for ($i = $min; $i < $max; $i = $i + $step) {
            $selected = '';
            if ($i == $defaultValue) {
                $selected = ' selected="selected" ';
            }
            $html .= '<option value="' . $i . '" ' . $selected . '>' . $i . '</option>';
        }
        $html .= '</select>';
        $html .= '</div>';
        $html .= '</div>';
        $this->formulario .= $html;
    }

    function createHidden($name, $value) {
        $html = '<input type="hidden" name="' . $name . '" value="' . $value . '" />';
        $this->formulario .= $html;
    }

    function createSubmitButton($name, $text) {
        $html = '<button class="btn btn-default pull-right" name="' . $name . '" type="submit">';
        $html .= '<i class="process-icon-save"></i>' . $text . '</button>';
        $this->formulario .= $html;
    }

    function createButton($name, $text, $extras=false, $type='button', $icon='plus') {
        $html = '<button class="btn btn-default pull-right" name="' . $name . '" type="'.$type.'"';
        if($extras && is_array($extras)) {
            foreach($extras AS $indice=>$extra) {
                $html.= ' '.$indice.'="'.$extra.'"';
            }
        }
        
        $html .= '>';
        $html .= '<i class="process-icon-'.$icon.'"></i>' . $text . '</button>';
        $this->formulario .= $html;
    }

    /**
     * Crea un select.
     * @param string $nombre
     * @param array $valores valor => visible
     * @param string $claveValor La clave en el array para los valores. Si el array es de una dimension se ignora.
     * @param string $claveVisible La clave en el array para el texto visible. Si el array es de una dimension se ignora.
     * @param string $valorSeleccionado
     * @return string
     */
    function createFormSelect($name, $text, $datos, $defaultValue, $title) {
        $html = '';
        $html .= '<div class="form-group">';
        $html .= '<label for="' . $name . '" class="control-label col-lg-3">';
        $html .= '<span title="' . $title . '">';
        $html .= $this->l($text);
        $html .= '</span>';
        $html .= '</label>';
        $html .= '<div class="col-lg-3">';
        $html .= '<select name="' . $name . '" id="' . $name . '">';
        foreach ($datos AS $valor => $texto) {
            $selected = '';
            if ($valor == $defaultValue) {
                $selected = ' selected="selected" ';
            }
            $html .= '<option value="' . $valor . '" ' . $selected . '>' . $texto . '</option>';
        }
        $html .= '</select>';
        $html .= '</div>';
        $html .= '</div>';
        $this->formulario .= $html;
    }

    
    public function generarSelectIdioma($name, $text, $defaultValue, $title) {
        $html = '';
        $html .= '<div class="form-group">';
        $html .= '<label for="' . $name . '" class="control-label col-lg-3">';
        $html .= '<span title="' . $title . '">';
        $html .= $this->l($text);
        $html .= '</span>';
        $html .= '</label>';
        $html .= '<div class="col-lg-3">';
        $html .= '<select name="'.$name.'" id="'.$name.'" class="selectIdioma">';
        $idiomas = Language::getLanguages();
        foreach ($idiomas AS $idioma) {
            $selected = '';
            if ($defaultValue == $idioma['id_lang']) {
                $selected = ' selected="selected" ';
            }
            $html .= '<option value="' . $idioma['id_lang'] . '" ' . $selected . '>' . $idioma['name'] . '</option>';
        }
        $html .= '</select>';
        $html .= '</div>';
        $html .= '</div>';
        reset($idiomas);
        $html .= '<style>';
        foreach($idiomas AS $idioma) {
             $html .= " .selectIdioma option[value='{$idioma['id_lang']}'] { background-image: url('.." . _THEME_LANG_DIR_ . "{$idioma['id_lang']}.jpg'); }";
        }
        $html .= '</style>';
        $html .= '<script>';
        $html .= ' var rutaImagenes="..'._THEME_LANG_DIR_.'"';
        $html .= '</script>';
        $this->formulario .= $html;
        
    }
    
    /*
      function crearSelect($nombre, $valores, $claveValor = '', $claveVisible = '', $valorSeleccionado = FALSE) {
      $html = "<select name='$nombre'>";
      foreach ($valores as $valor) {
      if (is_array($valor)) {
      $value = $valor[$claveValor];
      $texto = $valor[$claveVisible];
      } else {
      $value = $valor;
      $texto = $valor;
      }

      if ($valorSeleccionado !== FALSE && $value == $valorSeleccionado) {
      $seleccionado = 'selected="selected"';
      } else {
      $seleccionado = '';
      }

      $html .= "<option $seleccionado value='$value'>$texto</option>";
      }
      $html .= '</select>';

      $this->formulario .= $html;
      }
     */

    private function addCSS($css) {
        $tab = Tools::getValue('tab', 0);
        if (!$tab || ($tab && $tab != 'AdminSelfUpgrade')) {
            if ($this->context->controller instanceof stdClass) {
                $this->context->controller = new AdminModulesController();
            }
            $this->context->controller->addCss($this->_path . 'forms/' . $css, 'all');
        }
        return;
    }

    private function addJS($js) {
        $tab = Tools::getValue('tab', 0);       
        if (!$tab || ($tab && $tab != 'AdminSelfUpgrade')) {
            
            if ($this->context->controller instanceof stdClass) {
                $this->context->controller = new AdminModulesController();
            }
            $this->context->controller->addJs($this->_path . 'forms/' . $js);
        }
        return;
    }

}
